<?php


function joint_theme_setup() {

    $joint_theme_info = wp_get_theme();
    $GLOBALS['joint_theme_version'] = $joint_theme_info->get( 'Version' );

    // Image size for page block section
    add_image_size('joint_page_block', 1000, 700, true);


    if ( class_exists( 'Kirki' ) ) {

        // 1.3 Number of posts to display
        Kirki::add_field( 'joint_config', array(
            'type'        => 'number',
            'settings'    => 'homepage_banner_slider_num_setting',
            'label'       => esc_html__( 'Number Of Slider To Display', 'joint' ),
            'section'     => 'homepage_banner_section',
            'default'     => 3,
            'choices'     => array(
                'min'  => 1,
                'max'  => 15,
                'step' => 1,
            ),
            'priority'    => 10,
        ) );

        // 1.4 show/hide tags 
        Kirki::add_field( 'joint_config', array(
            'type'        => 'toggle',
            'settings'    => 'homepage_banner_slider_show_hide_tags',
            'label'       => esc_attr__( 'Show/Hide Tags', 'joint' ),
            'section'     => 'homepage_banner_section',
            'default'     => '1',
            'priority'    => 10,
        ) );

        // 1.4 show/hide Date 
        Kirki::add_field( 'joint_config', array(
            'type'        => 'toggle',
            'settings'    => 'homepage_banner_slider_show_hide_date',
            'label'       => esc_attr__( 'Show/Hide Date', 'joint' ),
            'section'     => 'homepage_banner_section',
            'default'     => '1',
            'priority'    => 10,
        ) );

        // 1.4 show/hide Author 
        Kirki::add_field( 'joint_config', array(
            'type'        => 'toggle',
            'settings'    => 'homepage_banner_slider_show_hide_author',
            'label'       => esc_attr__( 'Show/Hide Author', 'joint' ),
            'section'     => 'homepage_banner_section',
            'default'     => '1',
            'priority'    => 10,
        ) );

        /** Homepage Page block section **/
        Kirki::add_section( 'joint_config', array(
            'title'          => esc_attr__( 'Homepage Page Block section', 'joint' ),
            'panel'          => 'homepage_panel',
            'priority'       => 160,
        ) );

        /************* 8a.0 Homepage Page Block Section *********************/

        // 8a.0 Page block section
        Kirki::add_field( 'joint_config', array(
            'type'        => 'switch',
            'settings'    => 'homepage_pageblock_section_display',
            'label'       => esc_html__('Choose whether to display this section', 'joint' ),
            'section'     => 'homepage_pageblock_section',
            'default'     => '',
            'priority'    => 10,
            'choices'     => array(
                'on'  => esc_attr__( 'Display', 'joint' ),
                'off' => esc_attr__( 'Hide', 'joint' ),
            ),
        ) );


        // 8a.1 Block page dropdown
        Kirki::add_field( 'joint_config', array(
            'type'        => 'dropdown-pages',
            'settings'    => 'homepage_blockpage_setting',
            'label'       => esc_html__('Select the Page to display', 'joint' ),
            'section'     => 'homepage_pageblock_section',
            'default'     => '',
            'priority'    => 10,
        ) );
    }
    

}
add_action( 'after_setup_theme', 'joint_theme_setup' );

/**
 * Loads parent and child themes' style.css
 */
function joint_enqueue_styles() {

    global $joint_theme_version;
    
    wp_dequeue_style( 'bazzinga-style' );    
    wp_enqueue_style( 'joint-parent-style', get_template_directory_uri() . '/style.css', array(), esc_attr( $joint_theme_version ) );

    wp_enqueue_style( 'joint-style', get_stylesheet_uri(), array(), esc_attr( $joint_theme_version ) );

}

add_action( 'wp_enqueue_scripts', 'joint_enqueue_styles', 20 );




/*
=================================================
Header Navigation
@Action: bazzinga_navigation_header_fnc
=================================================
*/
function bazzinga_navigation_header_fnc(){
?>
 
 
<div class="navbar navbar-color-on-scroll navbar-expand-lg navbar-transparent" id="bazz_header_nav">
 
    <div class="container">

        <div class="inner-logo">    
            <div class="site-branding navbar-brand">
                <?php
                the_custom_logo();
                if ( is_front_page() && is_home() ) : ?>
                    <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                <?php else : ?>
                    <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                <?php
                endif;

                $description = get_bloginfo( 'description', 'display' );
                if ( $description || is_customize_preview() ) : ?>
                    <p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
                <?php
                endif; ?>
            </div><!-- .site-branding -->
        </div>

        <div class="inner-mainNav">
            <nav id="main-nav site-navigation" class="main-navigation  navbar-collapse">
                <!-- Mobile menu toggle button (hamburger/x icon) -->
                <input id="main-menu-state" type="checkbox" />
                <label class="main-menu-btn" for="main-menu-state">
                    <span class="main-menu-btn-icon"></span>
                    <?php esc_html_e('Toggle main menu visibility','joint'); ?>
                </label>
                <?php
                    wp_nav_menu( array(
                        'theme_location' => 'header-menu',
                        'container' => false,
                        'menu_class' => 'sm sm-clean',
                        'menu' => 'header-menu',
                        'fallback_cb'    => 'joint_primary_navigation_fallback',
                    ) );
                ?>
                <a href="javascript:void(0);"><i class="fa fa-search bazzinga_show_search"></i></a>
            </nav><!-- #site-navigation -->
        </div>
        <div class="header_search_form"  >
            <?php get_search_form(); ?>
            <a href="javascript:void(0);" class="header_search_close"><i class="fas fa-times-circle"></i></a>
        </div>
    </div>
</div>
<?php
}

// fallback for navigation
function joint_primary_navigation_fallback() {

        echo '<ul id="primary-menu" class="sm sm-clean" aria-expanded="false">';
        echo '<li><a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'Home', 'joint' ) . '</a></li>';

        $args = array(
            'posts_per_page' => 5,
            'post_type'      => 'page',
            'orderby'        => 'name',
            'order'          => 'ASC',
            );

        $the_query = new WP_Query( $args );

        if ( $the_query->have_posts() ) {
            while ( $the_query->have_posts() ) {
                $the_query->the_post();
                the_title( '<li><a href="' . esc_url( get_permalink() ) . '">', '</a></li>' );
            }

            wp_reset_postdata();
        }

        echo '</ul>';
    }




// Creative banner function override
function bazzinga_home_banner_sec_creative_fnc(){ 
    ?>
<section class="homepage_banner_wrap hero-image bazz_creative_style" data-aos="zoom-in"  data-aos-delay="800"  style="background-image: url(<?php if(has_post_thumbnail()){ echo esc_url( get_the_post_thumbnail_url() ); }?>);">
    <?php 
        if ( true == get_theme_mod( 'homepage_banner_display_setting', true ) ) :
    ?>
        <div class="hero-post-wrap">
            <div class="container">
                <div class="row">
                    <div class="col-md-10 col-lg-6 offset-md-2 offset-lg-6">
                    <div class="d-flex justify-content-end home_banner_wrap">   
                    <?php
                    $banner_post_num = get_theme_mod('homepage_banner_slider_num_setting', 3);

                    $homepage_banner_post_id= get_theme_mod('homepage_banner_post_display_setting');
                    if( $homepage_banner_post_id ){
                        
                        $bazzinga_banner_query  = new WP_Query( array( 
                                                        'cat' => absint( $homepage_banner_post_id ) , 
                                                        'posts_per_page' => absint( $banner_post_num ), 
                                                                ) );

                        while ( $bazzinga_banner_query->have_posts() ) : $bazzinga_banner_query->the_post();
                        ?>
                        <div class="hero-post article-post" data-aos="fade-up" data-aos-delay="1200">
                            <article class="homepage_banner_post" >
                                <div class="p-4">
                                    <div class="row">
                                        <div class="col-md-4" data-aos="fade-up">
                                            <div class="entry-meta">
                                                <?php
                                                if( get_theme_mod('homepage_banner_slider_show_hide_tags', '1') == 1 ){
                                                     if( has_tag() ){ ?>
                                                        <div class="blog-cat">
                                                            <i class="fas fa-tag"></i>
                                                            <?php the_tags( '', ', ', '' ); ?>
                                                        </div>
                                                    <?php } 
                                                }
                                                ?>
                                                <div class="blog_date_author">
                                                    <?php 
                                                    if( get_theme_mod('homepage_banner_slider_show_hide_date', '1') == 1 ){
                                                    ?>
                                                        <span class="blog_date"><i class="far fa-calendar"></i> <?php echo esc_html( get_the_date() ); ?> </span>
                                                    <?php } if( get_theme_mod('homepage_banner_slider_show_hide_author', '1') == 1 ){?>
                                                        <span class="blog_author"><i class="fas fa-user"></i> <?php the_author(); ?> </span>
                                                    <?php } ?>
                                                </div>
                                            </div><!-- .entry-meta -->
                                             
                                            <p><?php
                                                the_excerpt();
                                             ?>                             
                                            </p>
                                        </div>
                                        <div class="col-md-8">
                                            <?php if( has_post_thumbnail() ): ?>
                                                <figure>
                                                <img src="<?php echo esc_url(get_the_post_thumbnail_url(get_the_ID(),'bazzinga_post_image1')); ?>">
                                                        <?php the_category() ; ?>
                            
                                                </figure>
                                            <?php endif; ?>
                                            <div class="post-title">
                                                <h1>
                                                    <span class="heading-line">
                                                        <a class="pre-wrap-bg" href="<?php the_permalink();?>"><?php
                                                            the_title();
                                                        ?></a>
                                                    </span>
                                                </h1>
                                                <div class="banner_author_content">
                                                    <span class="author_label">
                                                        <?php esc_html_e('Author:' ,'joint'); ?>
                                                    </span> 
                                                    <span class="author_name">
                                                    <?php 
                                                        the_author();
                                                        ?>
                                                    </span>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </article>
                        </div>
                        <?php endwhile; wp_reset_postdata(); } ?> 
                    </div>
            </div>
        </div>
    </div>
</div>
<?php endif; ?>
</section>
<?php 
}

// banner override business
function bazzinga_home_banner_sec_business_fnc(){ 
    ?>
<section class="homepage_banner_wrap hero-image bazz_business_style"  data-aos="zoom-in"  data-aos-delay="800" style="background-image: url(<?php if(has_post_thumbnail()){ echo esc_url( get_the_post_thumbnail_url() ); } ?>);">
    <?php 
        if ( true == get_theme_mod( 'homepage_banner_display_setting', true ) ) :
    ?>
    <div class="hero-post-wrap">
        <div class="container">
            <div class="row">
                <div class="col-md-12">
                    <h1  data-aos="fade-up" data-aos-delay="1000">
                        <?php the_title(); ?>
                    </h1>
                </div>
            </div>

            <div class="row bazz_banner_header">
                <?php
                $banner_post_num = get_theme_mod('homepage_banner_slider_num_setting', 3);
                $homepage_banner_post_id= get_theme_mod('homepage_banner_post_display_setting');
                if( $homepage_banner_post_id ){
                    
                    $bazzinga_banner_query  = new WP_Query( array( 
                                                    'cat' => absint( $homepage_banner_post_id ) , 
                                                    'posts_per_page' => absint( $banner_post_num ),
                                                            ) );
                    $business_header_delay = 1200;

                    while ( $bazzinga_banner_query->have_posts() ) : $bazzinga_banner_query->the_post();
                    ?>
                        <div class="col-lg-3">
                            <article class="homepage_banner_post" data-aos="fade-up"  data-aos-delay="<?php echo esc_attr( $business_header_delay );?>">
                                <div class="hero-post article-post"  >
                                    <div class="p-md-4">
                                        <div class="post-title">
                                            <h2 >
                                                <a class="pre-wrap-bg" href="<?php the_permalink();?>"><?php
                                                    the_title();
                                                ?></a>
                                            </h2>
                                        </div>
                                        <div class="post-content">
                                            <p><?php echo wp_kses_post( wp_trim_words( get_the_content(), '8' ,'...' ) ); ?></p>
                                        </div>

                                        <a href="<?php the_permalink();?>" class="links bz-white">
                                            <?php esc_html_e( 'Read More', 'joint') ; ?>
                                        </a>

                                    </div>
                                </div>
                            </article>
                        </div>
                    <?php 
                    $business_header_delay = $business_header_delay+100;
                    endwhile; wp_reset_postdata(); } ?> 
                </div>
            </div>
        </div>
    </div>
<?php endif; ?>
</section>
<?php 
}

// classic banner override
function bazzinga_home_banner_sec_classic_fnc(){ 
    ?>
<section class="homepage_banner_wrap bazz_classic_style" >
    <div class="homepage_three_banner">
        <?php 
            if ( true == get_theme_mod( 'homepage_banner_display_setting', true ) ) :
            $homepage_banner_post_id= get_theme_mod('homepage_banner_post_display_setting');
            $banner_post_num = get_theme_mod('homepage_banner_slider_num_setting', 3);
            if( $homepage_banner_post_id ){
                
                $bazzinga_banner_query  = new WP_Query( array( 
                                                'cat' => absint( $homepage_banner_post_id ) , 
                                                'posts_per_page' => absint($banner_post_num),
                                                        ) );

                while ( $bazzinga_banner_query->have_posts() ) : $bazzinga_banner_query->the_post();
                ?>
                <article class="homepage_banner_post bazz_homepage_three" style="background-image: url(<?php if( has_post_thumbnail() ){ echo esc_url( get_the_post_thumbnail_url(get_the_ID(),'full') ); } ?>)" data-aos="zoom-in"  data-aos-delay="800" >
                    <div class="bazz_banner_caption text-center"  >
                        <div class="container">
                            <div class="row">
                                <div class="col-md-8 offset-md-2" data-aos="fade-up"  data-aos-delay="1200">
                                    <div class="post-title">
                                        <h1>
                                            <a class="pre-wrap-bg" href="<?php the_permalink();?>"><?php
                                                    the_title();
                                                ?></a> 
                                        </h1>
                                    </div>
                                    <p><?php the_excerpt(); ?></p>
                                    <a href="<?php the_permalink();?>" class="primary-btn btn"><?php esc_html_e( 'Read More', 'joint'); ?></a>
                                </div>
                            </div>
                        </div>
                    </div>
                </article>
            <?php endwhile; wp_reset_postdata(); } ?> 
        <?php endif; ?>
    </div>
</section>
<?php 
}

// for block page section
add_action('joint_block_page_section', 'joint_block_page_section_fnc');

/*
=================================================
block page section
@Action: joint_block_page_section
=================================================
*/
if ( ! function_exists( 'joint_block_page_section_fnc' ) ) :

function joint_block_page_section_fnc(){
    if ( true == get_theme_mod( 'homepage_pageblock_section_display', false )):
        $block_page_id = get_theme_mod('homepage_blockpage_setting');
        if($block_page_id):
             ?>
            <section class="bazz_pageblock_wrap">
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-lg-6 pl-lg-0" data-aos="fade-up"  data-aos-delay="5000">
                            <?php 
                                if( has_post_thumbnail( $block_page_id ) ){ ?>
                                <figure class="block_page_image" style="background-image:url(<?php echo esc_url( get_the_post_thumbnail_url( $block_page_id , 'joint_page_block') ); ?>)">
                                    </figure>
                            <?php } ?>              
                        </div>
                        <div class="col-lg-6 px-md-5 py-md-5">
                            <div class="block-page-text" data-aos="fade-up"  data-aos-delay="1000">
                                <div class="sub-headline aos-init aos-animate"><?php the_title();?></div>
                                <?php 
                                $bazz_block_page_text = get_post( absint($block_page_id) );
                                echo wp_kses_post( apply_filters('the_excerpt', $bazz_block_page_text->post_content) );
                                ?>
                                <a href="<?php echo esc_url( get_the_permalink( $block_page_id ) );?>" class="primary-btn btn">
                                    <?php esc_html_e('Read More', 'joint'); ?>
                                </a>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <?php 
        endif; // end of checking if id field is empty
    endif; // end of checking whether section is turned or or off
    }
endif;